.. _other_tools:

Other tools
===========

On top of the pipelines described in the major sections of the documentation, the pipeline comes bundled with several other, smaller tools, all accessible via the `paleomix` command. These tools are (briefly) described in this section.


paleomix coverage
-----------------

Calculates coverage for a BAM file, either for the entire genome or for specific regions.


paleomix depths
---------------

Calculates a depth histogram for a BAM file, either for the entire genome or for specific regions.


paleomix rmdup_collapsed
------------------------

Filters PCR duplicates for merged/collapsed paired-ended reads, such as those generated by AdapterRemoval with the `--collapse` option enabled. Unlike `SAMtools rmdup` or `Picard MarkDuplicates`, this tool identifies duplicates based on both the 5' and the 3' alignment coordinates of individual reads.

paleomix vcf_filter
-------------------

Quality filters for VCF records, similar to `vcfutils.pl varFilter`.


paleomix vcf_to_fasta
---------------------

The 'paleomix vcf\_to\_fasta' command is used to generate FASTA sequences from a VCF file, based either on a set of BED coordinates provided by the user, or for the entire genome covered by the VCF file. By default, heterozygous SNPs are represented using IUPAC codes.
